@@ -54,6 +54,9 @@ static gboolean bus_callback(GstBus* bus, GstMessage* message, gpointer user_dat
 	gint64 duration;
 	GList* next_dif_items;
 	GError* error = NULL;
+	GstObject* o;
+	gchar* s;
+	gchar* text;
 	
 	data = (Data*)user_data;
 	cleanup = FALSE;
@@ -65,7 +68,14 @@ static gboolean bus_callback(GstBus* bus, GstMessage* message, gpointer user_dat
 		cleanup = TRUE;
 	} else if (GST_MESSAGE_TYPE(message) == GST_MESSAGE_ERROR) {
 		gst_message_parse_error(message, &error, NULL);
-		show_message(error->message);
+		if ((o = GST_MESSAGE_SRC(message)) && (g_object_get(o, "location", &s, NULL), s)) {
+			text = g_strconcat(s, ": ", error->message, NULL);
+			g_free(s);
+		} else {
+			text = g_strdup(error->message);
+		}
+		show_message(text);
+		g_free(text);
 		g_error_free(error);
 
 		error_return = 1;
@@ -111,6 +121,7 @@ static void download_dif_item(DifItem* dif_item, GList* next_dif_items) {
 	GstElement* decodebin;
 	GstElement* wavenc;
 	gchar* s;
+	gchar* uri;
 	
 	data = g_malloc0(sizeof(Data));
 	data->next_dif_items = next_dif_items;
@@ -121,8 +132,10 @@ static void download_dif_item(DifItem* dif_item, GList* next_dif_items) {
 	gst_object_unref(bus);
 
 	src = gst_element_factory_make("gnomevfssrc", NULL);
-	s = g_strdup_printf("%s/%s.%lu", root_url, dif_item->path, (unsigned long)dif_item->timestamp);
-	g_object_set(src, "location", s, NULL);
+	s = g_uri_escape_string(dif_item->path, "/", FALSE);
+	uri = g_strdup_printf("%s/%s.%lu", root_url, s, (unsigned long)dif_item->timestamp);
+	g_object_set(src, "location", uri, NULL);
+	g_free(uri);
 	g_free(s);
 
 	decodebin = gst_element_factory_make("decodebin", NULL);
@@ -144,7 +157,7 @@ static void download_dif_items(GList* dif_items) {
 	gchar* s;
 	struct stat stat_buf;
 	
-	if (dif_items) {
+	if (dif_items && !error_return) {
 		dif_item = dif_items->data;
 		
 		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progress_bar), (gdouble)dif_item_index / n_dif_items);
